@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Muldis::D; # package
-    use version; our $VERSION = qv('0.24.0');
+    use version; our $VERSION = qv('0.25.0');
     # Note that Perl code only exists at all in this file in order to help
     # the CPAN indexer handle the distribution properly.
 } # package Muldis::D
@@ -29,7 +29,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Muldis::D version 0.24.0.
+This document is Muldis::D version 0.25.0.
 
 =head1 PREFACE
 
@@ -57,20 +57,21 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:'cpan:DUNCAND':'0.24.0'>.  It is the official/original (not
+C<Muldis_D:'http://muldis.com':'0.25.0'>.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<cpan:DUNCAND>), version C<0.24.0> (this number matches the
-VERSION pod in this file).  This multi-part document is named and organized
-with the expectation that many dialects, extensions, and core versions of
-it will exist over time, some of those under the original author's control,
-and some under the control of other parties.  The VERSIONING pod section in
-this file presents a formal method for specifying the fully-qualified name
-of a complete language derived from Muldis D, including any common base
-plus any dialects and extensions.  All code written in any dialect or
-derivation of Muldis D should begin by specifying the fully-qualified name
-of the language that it is written in, the format of the name as defined by
-said method, to make the code unambiguous to both human and machine (eg,
-implementing) readers of the code.  The method should be very future-proof.
+Darren Duncan (C<http://muldis.com>), version C<0.25.0> (this number
+matches the VERSION pod in this file).  This multi-part document is named
+and organized with the expectation that many dialects, extensions, and core
+versions of it will exist over time, some of those under the original
+author's control, and some under the control of other parties.  The
+L</VERSIONING> pod section in this file presents a formal method for
+specifying the fully-qualified name of a complete language derived from
+Muldis D, including any common base plus any dialects and extensions.  All
+code written in any dialect or derivation of Muldis D should begin by
+specifying the fully-qualified name of the language that it is written in,
+the format of the name as defined by said method, to make the code
+unambiguous to both human and machine (eg, implementing) readers of the
+code.  The method should be very future-proof.
 
 Muldis D is a computationally / Turing complete (and industrial strength)
 high-level programming language with fully integrated database
@@ -186,10 +187,10 @@ follow the formats that are valid as authority strings for the long names
 of Perl 6 packages, such as a CPAN identifier or an http url.
 
 For the official/original Muldis D language spec by Darren Duncan, that
-string is always C<cpan:DUNCAND> during the foreseeable future.
+string is always C<http://muldis.com> during the foreseeable future.
 
 If someone else wants to I<embrace and extend> Muldis D, then they must use
-their own (not C<cpan:DUNCAND>) base authority identifier, to prevent
+their own (not C<http://muldis.com>) base authority identifier, to prevent
 ambiguity, assist quality control, and give due credit.
 
 In this context, I<embrace and extend> means for someone to do any of the
@@ -218,37 +219,37 @@ top-level namespace (as opposed to in C<imp>).
 =head2 Base Version Number
 
 The third element of the Muldis D language name, at the very least when the
-base authority is C<cpan:DUNCAND>, is a multi-part base version number,
-which identifies the base language spec version between all those by the
-same authority, typically indicating the relative ages of the versions, the
-relative sizes of their deltas, and perhaps which development branches the
-versions are on.  The base version number is a sequence of unsigned
-integers that consists of at least 1 element, and either 3 or 4 elements is
-recommended (the official base version number has 3 elements); elements are
-ordered from most significant to least (eg, [major, minor, bug-fix]).  At
-the present time, the official spec version number to use is shown in the
-VERSION and DESCRIPTION pod of the current file, when corresponding to the
-spec containing that file.
+base authority is C<http://muldis.com>, is a multi-part base version
+number, which identifies the base language spec version between all those
+by the same authority, typically indicating the relative ages of the
+versions, the relative sizes of their deltas, and perhaps which development
+branches the versions are on.  The base version number is a sequence of
+unsigned integers that consists of at least 1 element, and either 3 or 4
+elements is recommended (the official base version number has 3 elements);
+elements are ordered from most significant to least (eg, [major, minor,
+bug-fix]).  At the present time, the official spec version number to use is
+shown in the VERSION and DESCRIPTION pod of the current file, when
+corresponding to the spec containing that file.
 
 =head2 Dialect
 
 The fourth element of the Muldis D language name, at the very least when
-the base authority is C<cpan:DUNCAND>, uniquely identifies which Muldis D
-language primary dialect the Muldis D code (that this fully-qualified
-language name is meta-data for) is formatted in; for example this may be
-one of several non-hosted plain-text variants, or one of several hosted
-data variants (each host language has its own ones).  This fourth element
-can either be some character string or be a sequence of 3+ elements.  In
-the first case, the character string is interpreted as the name of one of
-the several dialects included in the current multi-document, and the
-specific variant of said dialect is assumed to be whichever one is bundled
-with the already named base language authority+version.  In the second
-case, the sequence of elements is a dialect name plus authority plus
+the base authority is C<http://muldis.com>, uniquely identifies which
+Muldis D language primary dialect the Muldis D code (that this
+fully-qualified language name is meta-data for) is formatted in; for
+example this may be one of several non-hosted plain-text variants, or one
+of several hosted data variants (each host language has its own ones).
+This fourth element can either be some character string or be a sequence of
+3+ elements.  In the first case, the character string is interpreted as the
+name of one of the several dialects included in the current multi-document,
+and the specific variant of said dialect is assumed to be whichever one is
+bundled with the already named base language authority+version.  In the
+second case, the sequence of elements is a dialect name plus authority plus
 version plus whatever, for some spec definition not bundled with the
 current multi-document.  Note that a dialect specification can appear to
 provide features not in the underlying main spec, but code written in any
-dialect needs to be translatable to a standard dialect without changing
-the code's behavior.
+dialect needs to be translatable to a standard dialect without changing the
+code's behavior.
 
 See the following parts of the current multi-document for descriptions of
 bundled dialects (names subject to change):
@@ -300,76 +301,47 @@ suggesting improvements to the standard version.
 
 =head1 TRADEMARK POLICY
 
-The word MULDIS (in any letter case or font) is a Trademark (™), with
-Canadian registration pending (®), of Muldis Data Systems Inc.
-(L<http://www.muldis.com/>), which is wholly owned by Darren Duncan.  The
-trademark applies to computer database software and related services.
+MULDIS and MULDIS MULTIVERSE OF DISCOURSE are trademarks of Muldis Data
+Systems Inc. (L<http://www.muldis.com/>), which is wholly owned by Darren
+Duncan.  The trademarks apply to computer database software and related
+services.  See L<http://www.muldis.com/trademark_policy.html> for the full
+written details of Muldis Data Systems' trademark policy.
 
-The word MULDIS was invented as a new word, through contraction of the
-quasi-meaningful phrase MULTIVERSE OF DISCOURSE, by Darren Duncan for the
-express purpose of using that word as a distinguishing brand name for the
-products and services (and entity name) of Muldis Data Systems.  Said
-products and services are created for the world's betterment by way of the
-improved means to organize and share trustworthy data that their use
-enables.  Muldis Data Systems is obligated to protect the reputation and
-identity of its name and works, which should be evoked by the MULDIS brand.
+The word MULDIS is intended to be used as the distinguishing brand name for
+all the products and services of Muldis Data Systems.  So we would greatly
+appreciate it if in general you do not incorporate the word MULDIS into the
+name or logo of your website, business, product or service, but rather use
+your own distinct name (exceptions appear below).  It is, however, always
+okay to use the word MULDIS only in descriptions of your website, business,
+product or service to provide accurate information to the public about
+yourself.
 
-The trademark on MULDIS gives Muldis Data Systems the exclusive right to
-use the term to promote websites, businesses, products and services (such
-as the B<Muldis D> language and B<Muldis DB> software); however, we (Muldis
-Data Systems) are happy to give you permission to use the term under many
-circumstances without the need of any specific permission from us (in
-addition to what vanilla trademark law allows).
-
-The following is a general policy that tells you when you can refer to the
-word MULDIS without need of any specific permission from us:
-
-1.  You must make clear that you are not Muldis Data Systems and that
+If you do incorporate the word MULDIS into your names anyway, either
+because you have permission from us or you have some other good reason,
+then:  You must make clear that you are not Muldis Data Systems and that
 you do not represent Muldis Data Systems.  A simple or conspicuous
 disclaimer on your home page and product or service documentation is an
 excellent way of doing that.
 
-2.  You may not incorporate the word MULDIS into the name or logo of your
-website, business, product or service; but see points 4 thru 6 for limited
-exceptions to this.
+Please respect the conventions of the Perl community by not using the
+namespace C<Muldis::> at all for your own works, unless you have explicit
+permission to do so from Muldis Data Systems; that namespace is mainly just
+for our official works.  You can always use either the C<MuldisX::>
+namespace for related unofficial works, or some other namespace that is
+completely different.  Also as per conventions, its fine to use C<Muldis>
+within a Perl package name where that word is nested under some other
+project-specific namespace (for example, C<Foo::Storage::Muldis_DB> or
+C<Bar::Interface::Muldis_DB>), and the package serves to interact with a
+Muldis Data Systems work or service.
 
-3.  You may use the word MULDIS only in descriptions of your website,
-business, product or service to provide accurate information to the public
-about yourself.
+If you have made a language variant or extension based on the B<Muldis D>
+language, then please follow the naming conventions described in the
+VERSIONING (L<Muldis::D/VERSIONING>) documentation of the official
+B<Muldis D> language spec.
 
-4.  If you have made a language variant or extension based on the B<Muldis
-D> (L<Muldis::D>) language, then the fully qualified machine
-readable name of your work may, and in fact should, use the base name
-C<Muldis_D> as per the provisions of the VERSIONING documentation of the
-official Muldis D language spec.
-
-5.  The Perl package primary namespace C<Muldis::> is reserved for the
-official works of Muldis Data Systems (or works of third parties having
-explicit permission to use it).  If you have made a variant or extension of
-any Muldis Data Systems work in Perl (such as B<Muldis DB>; L<Muldis::DB>),
-you may use the C<MuldisX::> namespace for it as per CPAN conventions, or
-alternately just use your own distinct brand.  The same considerations
-apply to any secondary or tertiary (etc) namespaces where their ancestor
-namespaces serve as generic categorizing terms, such as C<Language::> or
-C<Data::> or C<Net::>.  For works you make in other programming languages
-than Perl, you should apply that language's or community's conventional
-naming practices for distinguishing official works from non-official ones.
-
-6.  If you have made a work or service that interacts with a Muldis Data
-Systems work or service for any reason, you may use the word MULDIS within
-the names of the components of your work or service that are involved in
-said interaction, as long as it is apparent by normal conventions that the
-word MULDIS is subservient to other parts of the name, such as your own
-main project name, and that the component is expressly a part of your work;
-for example, C<Foo::Storage::Muldis_DB> or C<Bar::Interface::Muldis_DB>.
-
-If you would like to use the word MULDIS for any other use, please contact
-Muldis Data Systems and we'll discuss a way to make that happen.  Assuming
-that you agree that our rights to the MULDIS trademark are valid and
-superior to yours, and that you take appropriate steps to ensure that
-people don't confuse you with us, then we should be able to make things
-work out.  If you've already started using the word MULDIS in a way that
-would require permission, don't panic, but please contact us.
+If you would like to use (or have already used) the word MULDIS for any use
+that ought to require permission, please contact Muldis Data Systems and
+we'll discuss a way to make that happen.
 
 =head1 ACKNOWLEDGEMENTS
 
